@@ -1,11 +1,12 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-06-11'; # DATE
-our $VERSION = '1.14'; # VERSION
+our $DATE = '2015-06-17'; # DATE
+our $VERSION = '1.15'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
+use Devel::Confess;
 
 use Capture::Tiny qw(capture);
 use Data::Dumper;
@@ -134,7 +135,7 @@ sub pericmd_ok {
 }
 
 1;
-# ABSTRACT: Test library for Perinci::CmdLine{::Classic,::Lite,::Inline}
+# ABSTRACT: Common test suite for Perinci::CmdLine::{Lite,Classic,Inline}
 
 __END__
 
@@ -144,11 +145,11 @@ __END__
 
 =head1 NAME
 
-Test::Perinci::CmdLine - Test library for Perinci::CmdLine{::Classic,::Lite,::Inline}
+Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,Inline}
 
 =head1 VERSION
 
-This document describes version 1.14 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-06-11.
+This document describes version 1.15 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-06-17.
 
 =head1 SEE ALSO
 
